@@ -1,11 +1,12 @@
+#![warn(missing_docs)]
 //! Parses a `Vec<u8>` as an byte sequence with ansi colors to
-//! [`tui::text::Text`](https://docs.rs/tui/0.14.0/tui/text/struct.Text.html).  
+//! [`tui::text::Text`][Text].  
 //!
 //! Invalid ansi colors / sequences will be ignored.  
 //!
 //!
 //! Supported features
-//! - UTF-8 using `String::from_utf8` or [`simdutf8`](https://github.com/rusticstuff/simdutf8).
+//! - UTF-8 using `String::from_utf8` or [`simdutf8`][simdutf8].
 //! - Most stuff like **Bold** / *Italic* / <u>Underline</u> / ~~Striketrhough~~.
 //! - Supports 4-bit color palletes.
 //! - Supports 8-bit color.
@@ -30,17 +31,18 @@
 //! let text = ansi_to_text(buffer);
 //! ```
 //!
-//! If you want to use [`simdutf8`](https://github.com/rusticstuff/simdutf8) instead of `String::from_utf8()`  
+//! If you want to use [`simdutf8`][simdutf8] instead of `String::from_utf8()`  
 //! for parsing UTF-8 then enable optional feature `simd`  
+//!  
+//! [Text]: https://docs.rs/tui/0.15.0/tui/text/struct.Text.html
+//! [ansi-to-tui]: https://github.com/uttarayan21/ansi-to-tui
+//! [simdutf8]: https://github.com/rusticstuff/simdutf8
 
 mod ansi;
 mod code;
-mod color;
 mod error;
 mod stack;
 
-pub use ansi::ansi_to_text;
-pub use ansi::ansi_to_text_override_style;
+pub use ansi::{ansi_to_text, ansi_to_text_override_style};
 pub use code::AnsiCode;
-pub use color::AnsiColor;
 pub use error::Error;
